package com.its.vds.stat.server.dao.mapper;

import com.its.vds.stat.server.dto.VdsStatTimeDto;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface VdsStatMapper {

    int delVdsDtctHs(@Param("obj") VdsStatTimeDto obj);
    int delVdsDtct15MinStat(@Param("obj") VdsStatTimeDto obj);
    int delVdsDtctHhStat(@Param("obj") VdsStatTimeDto obj);
    int delVdsDtctDdStat(@Param("obj") VdsStatTimeDto obj);

    int crtVdsDtctHs(@Param("obj") VdsStatTimeDto obj);
    int crtVdsDtct15MinStat(@Param("obj") VdsStatTimeDto obj);
    int crtVdsDtctHhStat(@Param("obj") VdsStatTimeDto obj);
    int crtVdsDtctDdStat(@Param("obj") VdsStatTimeDto obj);
    int crtVdsDtctMnStat(@Param("obj") VdsStatTimeDto obj);
    int crtVdsDtctYyStat(@Param("obj") VdsStatTimeDto obj);

}
